"use strict";

let hl = require("highland");
let utils = require("./utils");
let R = require("ramda");
const BeneLogger = require('bene-logger');
const tz = require('timezone/loaded');

module.exports = (config, db) => (req, res, next) => {

    const publicationId = req.params.publicationId;
    const escenicId = req.params.escenicId;
    const source = req.params.source;

    const logger = new BeneLogger({logging: config.logging.enabled});

    logger.setDefaults({
        tag_id: `${source}.${escenicId}`,
        source: source,
        service_name: 'apps-api'
    });

    logger.info('Processing Sections Request');
    logger.time('Finished Sections Request');

    const articlesEndpoint = !req.query.cache || req.query.cache !== "false" ? config.cacheEndpoint : config.articleEndpoint;
    
    const stream = hl(db.tag.find({
        "where": {
            "tag_id": `${source}.${escenicId}`
        }
    }))
        .reject(R.isNil)
        .invoke("get", {"plain": true})
        .pluck("id")
        .flatMap(id => {
            return hl(db.article_tag.findAll({
                "where": {
                    "tag_id": id,
                    "published_date": {
                        "$and": {
                            "$ne": null,
                            "$lte": tz(new Date(), '%Y-%m-%dT%H:%M:%S.%3N%^z', 'UTC')
                        }
                    }
                },
                "limit": 30,
                "order": [[
                    'published_date',
                    'DESC'
                ]]
            }));
        })
        .sequence()
        .invoke("get", {"plain": true})
        .pluck("article_id");

    const GetArticle = utils.makeArticleRequest(logger, articlesEndpoint, source, publicationId);
    const NotFound = utils.notFound(`${source}/${publicationId}/tags/${escenicId || ""} not available`);

    utils.getArticlesInParallel(logger, GetArticle, NotFound, stream)
        .sequence()
        .reject(utils.shouldBeExcluded)
        .collect()
        .map(utils.addMeta)
        .toCallback(utils.sendResponse(logger, res, next));
};
